@@ -112,6 +112,12 @@ const (
 	// PutBucketCorsAction - PutBucketCors Rest API action.
 	PutBucketCorsAction = "s3:PutBucketCors"
 
+	//  PutBucketQOSAction - allow set QOS configuration
+	PutBucketQOSAction = "s3:PutBucketQOS"
+
+	//  GetBucketQOSAction - allow get QOS configuration
+	GetBucketQOSAction = "s3:GetBucketQOS"
+
 	// PutObjectAction - PutObject Rest API action.
 	PutObjectAction = "s3:PutObject"
 
@@ -216,77 +222,239 @@ const (
 	// CreateSessionAction - S3Express REST API action
 	CreateSessionAction = "s3express:CreateSession"
 
+	// S3TablesCreateNamespaceAction maps to the AWS `CreateNamespace` S3 Tables action.
+	S3TablesCreateNamespaceAction Action = "s3tables:CreateNamespace"
+
+	// S3TablesCreateTableAction maps to the AWS `CreateTable` S3 Tables action.
+	S3TablesCreateTableAction Action = "s3tables:CreateTable"
+
+	// S3TablesCreateTableBucketAction maps to the AWS `CreateTableBucket` S3 Tables action.
+	S3TablesCreateTableBucketAction Action = "s3tables:CreateTableBucket"
+
+	// S3TablesDeleteNamespaceAction maps to the AWS `DeleteNamespace` S3 Tables action.
+	S3TablesDeleteNamespaceAction Action = "s3tables:DeleteNamespace"
+
+	// S3TablesDeleteTableAction maps to the AWS `DeleteTable` S3 Tables action.
+	S3TablesDeleteTableAction Action = "s3tables:DeleteTable"
+
+	// S3TablesDeleteTableBucketAction maps to the AWS `DeleteTableBucket` S3 Tables action.
+	S3TablesDeleteTableBucketAction Action = "s3tables:DeleteTableBucket"
+
+	// S3TablesDeleteTableBucketEncryptionAction maps to the AWS `DeleteTableBucketEncryption` S3 Tables action.
+	S3TablesDeleteTableBucketEncryptionAction Action = "s3tables:DeleteTableBucketEncryption"
+
+	// S3TablesDeleteTableBucketPolicyAction maps to the AWS `DeleteTableBucketPolicy` S3 Tables action.
+	S3TablesDeleteTableBucketPolicyAction Action = "s3tables:DeleteTableBucketPolicy"
+
+	// S3TablesDeleteTablePolicyAction maps to the AWS `DeleteTablePolicy` S3 Tables action.
+	S3TablesDeleteTablePolicyAction Action = "s3tables:DeleteTablePolicy"
+
+	// S3TablesGetNamespaceAction maps to the AWS `GetNamespace` S3 Tables action.
+	S3TablesGetNamespaceAction Action = "s3tables:GetNamespace"
+
+	// S3TablesGetTableAction maps to the AWS `GetTable` S3 Tables action.
+	S3TablesGetTableAction Action = "s3tables:GetTable"
+
+	// S3TablesGetTableBucketAction maps to the AWS `GetTableBucket` S3 Tables action.
+	S3TablesGetTableBucketAction Action = "s3tables:GetTableBucket"
+
+	// S3TablesGetTableBucketEncryptionAction maps to the AWS `GetTableBucketEncryption` S3 Tables action.
+	S3TablesGetTableBucketEncryptionAction Action = "s3tables:GetTableBucketEncryption"
+
+	// S3TablesGetTableBucketMaintenanceConfigurationAction maps to the AWS `GetTableBucketMaintenanceConfiguration` S3 Tables action.
+	S3TablesGetTableBucketMaintenanceConfigurationAction Action = "s3tables:GetTableBucketMaintenanceConfiguration"
+
+	// S3TablesGetTableBucketPolicyAction maps to the AWS `GetTableBucketPolicy` S3 Tables action.
+	S3TablesGetTableBucketPolicyAction Action = "s3tables:GetTableBucketPolicy"
+
+	// S3TablesGetTableDataAction maps to the AWS `GetTableData` S3 Tables action.
+	S3TablesGetTableDataAction Action = "s3tables:GetTableData"
+
+	// S3TablesGetTableEncryptionAction maps to the AWS `GetTableEncryption` S3 Tables action.
+	S3TablesGetTableEncryptionAction Action = "s3tables:GetTableEncryption"
+
+	// S3TablesGetTableMaintenanceConfigurationAction maps to the AWS `GetTableMaintenanceConfiguration` S3 Tables action.
+	S3TablesGetTableMaintenanceConfigurationAction Action = "s3tables:GetTableMaintenanceConfiguration"
+
+	// S3TablesGetTableMaintenanceJobStatusAction maps to the AWS `GetTableMaintenanceJobStatus` S3 Tables action.
+	S3TablesGetTableMaintenanceJobStatusAction Action = "s3tables:GetTableMaintenanceJobStatus"
+
+	// S3TablesGetTableMetadataLocationAction maps to the AWS `GetTableMetadataLocation` S3 Tables action.
+	S3TablesGetTableMetadataLocationAction Action = "s3tables:GetTableMetadataLocation"
+
+	// S3TablesGetTablePolicyAction maps to the AWS `GetTablePolicy` S3 Tables action.
+	S3TablesGetTablePolicyAction Action = "s3tables:GetTablePolicy"
+
+	// S3TablesListNamespacesAction maps to the AWS `ListNamespaces` S3 Tables action.
+	S3TablesListNamespacesAction Action = "s3tables:ListNamespaces"
+
+	// S3TablesListTableBucketsAction maps to the AWS `ListTableBuckets` S3 Tables action.
+	S3TablesListTableBucketsAction Action = "s3tables:ListTableBuckets"
+
+	// S3TablesListTablesAction maps to the AWS `ListTables` S3 Tables action.
+	S3TablesListTablesAction Action = "s3tables:ListTables"
+
+	// S3TablesPutTableBucketEncryptionAction maps to the AWS `PutTableBucketEncryption` S3 Tables action.
+	S3TablesPutTableBucketEncryptionAction Action = "s3tables:PutTableBucketEncryption"
+
+	// S3TablesPutTableBucketMaintenanceConfigurationAction maps to the AWS `PutTableBucketMaintenanceConfiguration` S3 Tables action.
+	S3TablesPutTableBucketMaintenanceConfigurationAction Action = "s3tables:PutTableBucketMaintenanceConfiguration"
+
+	// S3TablesPutTableBucketPolicyAction maps to the AWS `PutTableBucketPolicy` S3 Tables action.
+	S3TablesPutTableBucketPolicyAction Action = "s3tables:PutTableBucketPolicy"
+
+	// S3TablesPutTableDataAction maps to the AWS `PutTableData` S3 Tables action.
+	S3TablesPutTableDataAction Action = "s3tables:PutTableData"
+
+	// S3TablesPutTableEncryptionAction maps to the AWS `PutTableEncryption` S3 Tables action.
+	S3TablesPutTableEncryptionAction Action = "s3tables:PutTableEncryption"
+
+	// S3TablesPutTableMaintenanceConfigurationAction maps to the AWS `PutTableMaintenanceConfiguration` S3 Tables action.
+	S3TablesPutTableMaintenanceConfigurationAction Action = "s3tables:PutTableMaintenanceConfiguration"
+
+	// S3TablesPutTablePolicyAction maps to the AWS `PutTablePolicy` S3 Tables action.
+	S3TablesPutTablePolicyAction Action = "s3tables:PutTablePolicy"
+
+	// S3TablesRenameTableAction maps to the AWS `RenameTable` S3 Tables action.
+	S3TablesRenameTableAction Action = "s3tables:RenameTable"
+
+	// S3TablesUpdateTableMetadataLocationAction maps to the AWS `UpdateTableMetadataLocation` S3 Tables action.
+	S3TablesUpdateTableMetadataLocationAction Action = "s3tables:UpdateTableMetadataLocation"
+
+	// S3TablesCreateWarehouseAction is a MinIO extension for Iceberg warehouse provisioning.
+	S3TablesCreateWarehouseAction Action = "s3tables:CreateWarehouse"
+
+	// S3TablesListWarehousesAction is a MinIO extension for listing Iceberg warehouses.
+	S3TablesListWarehousesAction Action = "s3tables:ListWarehouses"
+
+	// S3TablesCommitMultiTableTransactionAction is a MinIO extension enabling multi-table transactions.
+	S3TablesCommitMultiTableTransactionAction Action = "s3tables:CommitMultiTableTransaction"
+
+	// S3TablesGetConfigAction is a MinIO extension for retrieving catalog configuration.
+	S3TablesGetConfigAction Action = "s3tables:GetConfig"
+
+	// S3TablesTableMetricsAction is a MinIO extension exposing table metrics.
+	S3TablesTableMetricsAction Action = "s3tables:TableMetrics"
+
+	// S3TablesUpdateTableAction is a MinIO extension for Iceberg-compatible table updates.
+	S3TablesUpdateTableAction Action = "s3tables:UpdateTable"
+
 	// AllActions - all API actions
 	AllActions = "s3:*"
+
+	// AllS3TablesActions - all Amazon S3 Tables actions
+	AllS3TablesActions = "s3tables:*"
 )
 
-// List of all supported actions.
-var supportedActions = map[Action]struct{}{
-	AbortMultipartUploadAction:             {},
-	CreateBucketAction:                     {},
-	DeleteBucketAction:                     {},
-	ForceDeleteBucketAction:                {},
-	DeleteBucketPolicyAction:               {},
-	DeleteBucketCorsAction:                 {},
-	DeleteObjectAction:                     {},
-	GetBucketLocationAction:                {},
-	GetBucketNotificationAction:            {},
-	GetBucketPolicyAction:                  {},
-	GetBucketCorsAction:                    {},
-	GetObjectAction:                        {},
-	HeadBucketAction:                       {},
-	ListAllMyBucketsAction:                 {},
-	ListBucketAction:                       {},
-	GetBucketPolicyStatusAction:            {},
-	ListBucketVersionsAction:               {},
-	ListBucketMultipartUploadsAction:       {},
-	ListenNotificationAction:               {},
-	ListenBucketNotificationAction:         {},
-	ListMultipartUploadPartsAction:         {},
-	PutBucketLifecycleAction:               {},
-	GetBucketLifecycleAction:               {},
-	PutBucketNotificationAction:            {},
-	PutBucketPolicyAction:                  {},
-	PutBucketCorsAction:                    {},
-	PutObjectAction:                        {},
-	BypassGovernanceRetentionAction:        {},
-	PutObjectRetentionAction:               {},
-	GetObjectRetentionAction:               {},
-	GetObjectLegalHoldAction:               {},
-	PutObjectLegalHoldAction:               {},
-	GetBucketObjectLockConfigurationAction: {},
-	PutBucketObjectLockConfigurationAction: {},
-	GetBucketTaggingAction:                 {},
-	PutBucketTaggingAction:                 {},
-	GetObjectVersionAction:                 {},
-	GetObjectAttributesAction:              {},
-	GetObjectVersionAttributesAction:       {},
-	GetObjectVersionTaggingAction:          {},
-	DeleteObjectVersionAction:              {},
-	DeleteObjectVersionTaggingAction:       {},
-	PutObjectVersionTaggingAction:          {},
-	GetObjectTaggingAction:                 {},
-	PutObjectTaggingAction:                 {},
-	DeleteObjectTaggingAction:              {},
-	PutBucketEncryptionAction:              {},
-	GetBucketEncryptionAction:              {},
-	PutBucketVersioningAction:              {},
-	GetBucketVersioningAction:              {},
-	GetReplicationConfigurationAction:      {},
-	PutReplicationConfigurationAction:      {},
-	ReplicateObjectAction:                  {},
-	ReplicateDeleteAction:                  {},
-	ReplicateTagsAction:                    {},
-	GetObjectVersionForReplicationAction:   {},
-	RestoreObjectAction:                    {},
-	ResetBucketReplicationStateAction:      {},
-	PutObjectFanOutAction:                  {},
-	CreateSessionAction:                    {},
-	AllActions:                             {},
+// SupportedActions - list of all supported actions.
+var SupportedActions = map[Action]struct{}{
+	AbortMultipartUploadAction:                           {},
+	CreateBucketAction:                                   {},
+	DeleteBucketAction:                                   {},
+	ForceDeleteBucketAction:                              {},
+	DeleteBucketPolicyAction:                             {},
+	DeleteBucketCorsAction:                               {},
+	DeleteObjectAction:                                   {},
+	GetBucketLocationAction:                              {},
+	GetBucketNotificationAction:                          {},
+	GetBucketPolicyAction:                                {},
+	GetBucketCorsAction:                                  {},
+	GetObjectAction:                                      {},
+	HeadBucketAction:                                     {},
+	ListAllMyBucketsAction:                               {},
+	ListBucketAction:                                     {},
+	GetBucketPolicyStatusAction:                          {},
+	ListBucketVersionsAction:                             {},
+	ListBucketMultipartUploadsAction:                     {},
+	ListenNotificationAction:                             {},
+	ListenBucketNotificationAction:                       {},
+	ListMultipartUploadPartsAction:                       {},
+	PutBucketLifecycleAction:                             {},
+	GetBucketLifecycleAction:                             {},
+	PutBucketNotificationAction:                          {},
+	PutBucketPolicyAction:                                {},
+	PutBucketCorsAction:                                  {},
+	PutBucketQOSAction:                                   {},
+	GetBucketQOSAction:                                   {},
+	PutObjectAction:                                      {},
+	BypassGovernanceRetentionAction:                      {},
+	PutObjectRetentionAction:                             {},
+	GetObjectRetentionAction:                             {},
+	GetObjectLegalHoldAction:                             {},
+	PutObjectLegalHoldAction:                             {},
+	GetBucketObjectLockConfigurationAction:               {},
+	PutBucketObjectLockConfigurationAction:               {},
+	GetBucketTaggingAction:                               {},
+	PutBucketTaggingAction:                               {},
+	GetObjectVersionAction:                               {},
+	GetObjectAttributesAction:                            {},
+	GetObjectVersionAttributesAction:                     {},
+	GetObjectVersionTaggingAction:                        {},
+	DeleteObjectVersionAction:                            {},
+	DeleteObjectVersionTaggingAction:                     {},
+	PutObjectVersionTaggingAction:                        {},
+	GetObjectTaggingAction:                               {},
+	PutObjectTaggingAction:                               {},
+	DeleteObjectTaggingAction:                            {},
+	PutBucketEncryptionAction:                            {},
+	GetBucketEncryptionAction:                            {},
+	PutBucketVersioningAction:                            {},
+	GetBucketVersioningAction:                            {},
+	GetReplicationConfigurationAction:                    {},
+	PutReplicationConfigurationAction:                    {},
+	ReplicateObjectAction:                                {},
+	ReplicateDeleteAction:                                {},
+	ReplicateTagsAction:                                  {},
+	GetObjectVersionForReplicationAction:                 {},
+	RestoreObjectAction:                                  {},
+	ResetBucketReplicationStateAction:                    {},
+	PutObjectFanOutAction:                                {},
+	CreateSessionAction:                                  {},
+	S3TablesCreateNamespaceAction:                        {},
+	S3TablesCreateTableAction:                            {},
+	S3TablesCreateTableBucketAction:                      {},
+	S3TablesDeleteNamespaceAction:                        {},
+	S3TablesDeleteTableAction:                            {},
+	S3TablesDeleteTableBucketAction:                      {},
+	S3TablesDeleteTableBucketEncryptionAction:            {},
+	S3TablesDeleteTableBucketPolicyAction:                {},
+	S3TablesDeleteTablePolicyAction:                      {},
+	S3TablesGetNamespaceAction:                           {},
+	S3TablesGetTableAction:                               {},
+	S3TablesGetTableBucketAction:                         {},
+	S3TablesGetTableBucketEncryptionAction:               {},
+	S3TablesGetTableBucketMaintenanceConfigurationAction: {},
+	S3TablesGetTableBucketPolicyAction:                   {},
+	S3TablesGetTableDataAction:                           {},
+	S3TablesGetTableEncryptionAction:                     {},
+	S3TablesGetTableMaintenanceConfigurationAction:       {},
+	S3TablesGetTableMaintenanceJobStatusAction:           {},
+	S3TablesGetTableMetadataLocationAction:               {},
+	S3TablesGetTablePolicyAction:                         {},
+	S3TablesListNamespacesAction:                         {},
+	S3TablesListTableBucketsAction:                       {},
+	S3TablesListTablesAction:                             {},
+	S3TablesPutTableBucketEncryptionAction:               {},
+	S3TablesPutTableBucketMaintenanceConfigurationAction: {},
+	S3TablesPutTableBucketPolicyAction:                   {},
+	S3TablesPutTableDataAction:                           {},
+	S3TablesPutTableEncryptionAction:                     {},
+	S3TablesPutTableMaintenanceConfigurationAction:       {},
+	S3TablesPutTablePolicyAction:                         {},
+	S3TablesRenameTableAction:                            {},
+	S3TablesUpdateTableMetadataLocationAction:            {},
+	S3TablesCreateWarehouseAction:                        {},
+	S3TablesListWarehousesAction:                         {},
+	S3TablesCommitMultiTableTransactionAction:            {},
+	S3TablesGetConfigAction:                              {},
+	S3TablesTableMetricsAction:                           {},
+	S3TablesUpdateTableAction:                            {},
+	AllActions:                                           {},
+	AllS3TablesActions:                                   {},
 }
 
-// List of all supported object actions.
-var supportedObjectActions = map[Action]struct{}{
+// SupportedObjectActions - list of all supported object actions.
+var SupportedObjectActions = map[Action]struct{}{
 	AllActions:                           {},
 	AbortMultipartUploadAction:           {},
 	DeleteObjectAction:                   {},
@@ -319,7 +487,7 @@ var supportedObjectActions = map[Action]struct{}{
 
 // IsObjectAction - returns whether action is object type or not.
 func (action Action) IsObjectAction() bool {
-	for supAction := range supportedObjectActions {
+	for supAction := range SupportedObjectActions {
 		if action.Match(supAction) {
 			return true
 		}
@@ -334,7 +502,7 @@ func (action Action) Match(a Action) bool {
 
 // IsValid - checks if action is valid or not.
 func (action Action) IsValid() bool {
-	for supAction := range supportedActions {
+	for supAction := range SupportedActions {
 		if action.Match(supAction) {
 			return true
 		}
@@ -375,6 +543,17 @@ func createActionConditionKeyMap() ActionConditionKeyMap {
 		allSupportedKeys = append(allSupportedKeys, keyName.ToKey())
 	}
 
+	s3TablesNamespaceKey := condition.S3TablesNamespace.ToKey()
+	s3TablesTableNameKey := condition.S3TablesTableName.ToKey()
+	s3TablesKMSKeyKey := condition.S3TablesKMSKeyArn.ToKey()
+	s3TablesSSEAlgorithmKey := condition.S3TablesSSEAlgorithm.ToKey()
+
+	withCommon := func(keys ...condition.Key) condition.KeySet {
+		merged := append([]condition.Key{}, commonKeys...)
+		merged = append(merged, keys...)
+		return condition.NewKeySet(merged...)
+	}
+
 	return ActionConditionKeyMap{
 		AllActions: condition.NewKeySet(allSupportedKeys...),
 
@@ -573,5 +752,52 @@ func createActionConditionKeyMap() ActionConditionKeyMap {
 		RestoreObjectAction:               condition.NewKeySet(commonKeys...),
 		ResetBucketReplicationStateAction: condition.NewKeySet(commonKeys...),
 		PutObjectFanOutAction:             condition.NewKeySet(commonKeys...),
+
+		// S3 Tables actions
+		AllS3TablesActions: withCommon(
+			s3TablesNamespaceKey,
+			s3TablesTableNameKey,
+			s3TablesKMSKeyKey,
+			s3TablesSSEAlgorithmKey,
+		),
+		S3TablesCreateNamespaceAction:                        withCommon(),
+		S3TablesCreateTableAction:                            withCommon(s3TablesNamespaceKey, s3TablesKMSKeyKey, s3TablesSSEAlgorithmKey),
+		S3TablesCreateTableBucketAction:                      withCommon(s3TablesKMSKeyKey, s3TablesSSEAlgorithmKey),
+		S3TablesDeleteNamespaceAction:                        withCommon(s3TablesNamespaceKey),
+		S3TablesDeleteTableAction:                            withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesDeleteTableBucketAction:                      withCommon(),
+		S3TablesDeleteTableBucketEncryptionAction:            withCommon(),
+		S3TablesDeleteTableBucketPolicyAction:                withCommon(),
+		S3TablesDeleteTablePolicyAction:                      withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesGetNamespaceAction:                           withCommon(s3TablesNamespaceKey),
+		S3TablesGetTableAction:                               withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesGetTableBucketAction:                         withCommon(),
+		S3TablesGetTableBucketEncryptionAction:               withCommon(),
+		S3TablesGetTableBucketMaintenanceConfigurationAction: withCommon(),
+		S3TablesGetTableBucketPolicyAction:                   withCommon(),
+		S3TablesGetTableDataAction:                           withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesGetTableEncryptionAction:                     withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesGetTableMaintenanceConfigurationAction:       withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesGetTableMaintenanceJobStatusAction:           withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesGetTableMetadataLocationAction:               withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesGetTablePolicyAction:                         withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesListNamespacesAction:                         withCommon(),
+		S3TablesListTableBucketsAction:                       withCommon(),
+		S3TablesListTablesAction:                             withCommon(s3TablesNamespaceKey),
+		S3TablesPutTableBucketEncryptionAction:               withCommon(s3TablesKMSKeyKey, s3TablesSSEAlgorithmKey),
+		S3TablesPutTableBucketMaintenanceConfigurationAction: withCommon(),
+		S3TablesPutTableBucketPolicyAction:                   withCommon(),
+		S3TablesPutTableDataAction:                           withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesPutTableEncryptionAction:                     withCommon(s3TablesNamespaceKey, s3TablesKMSKeyKey, s3TablesSSEAlgorithmKey),
+		S3TablesPutTableMaintenanceConfigurationAction:       withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesPutTablePolicyAction:                         withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesRenameTableAction:                            withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesUpdateTableMetadataLocationAction:            withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesCreateWarehouseAction:                        withCommon(s3TablesKMSKeyKey, s3TablesSSEAlgorithmKey),
+		S3TablesListWarehousesAction:                         withCommon(),
+		S3TablesCommitMultiTableTransactionAction:            withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesGetConfigAction:                              withCommon(),
+		S3TablesTableMetricsAction:                           withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
+		S3TablesUpdateTableAction:                            withCommon(s3TablesNamespaceKey, s3TablesTableNameKey),
 	}
 }
