@@ -168,10 +168,6 @@ func (actionSet *ActionSet) UnmarshalJSON(data []byte) error {
 		return err
 	}
 
-	if sset.IsEmpty() {
-		return Errorf("empty actions not allowed")
-	}
-
 	*actionSet = make(ActionSet)
 	for _, s := range sset.ToSlice() {
 		actionSet.Add(Action(s))
@@ -229,3 +225,13 @@ func NewActionSet(actions ...Action) ActionSet {
 
 	return actionSet
 }
+
+// NewActionStrings - creates new action set from strings.
+func NewActionStrings(actions ...string) ActionSet {
+	actionSet := make(ActionSet, len(actions))
+	for _, action := range actions {
+		actionSet.Add(Action(action))
+	}
+
+	return actionSet
+}
