@@ -89,8 +89,10 @@ func TestResourceIsValid(t *testing.T) {
 		{NewResource("mybucket?0/2010/photos/*"), true},
 		{NewResource("mybucket"), true},
 		{NewResource("mybucket?0"), true},
+		{Resource{Pattern: "us-east-1:111122223333:bucket/demo/table/*", Type: ResourceARNS3Tables}, true},
 		{NewResource("/*"), false},
 		{NewResource(""), false},
+		{Resource{Pattern: "", Type: ResourceARNS3Tables}, false},
 
 		{NewKMSResource("*"), true},
 		{NewKMSResource("mykey*"), true},
@@ -160,6 +162,7 @@ func TestResourceMarshalJSON(t *testing.T) {
 		{NewResource("mybucket/*"), []byte(`"arn:aws:s3:::mybucket/*"`), false},
 		{NewResource("mybucket*/myobject"), []byte(`"arn:aws:s3:::mybucket*/myobject"`), false},
 		{NewResource("mybucket?0/2010/photos/*"), []byte(`"arn:aws:s3:::mybucket?0/2010/photos/*"`), false},
+		{Resource{Pattern: "bucket/demo/table/*", Type: ResourceARNS3Tables}, []byte(`"arn:aws:s3tables:::bucket/demo/table/*"`), false},
 		{Resource{}, nil, true},
 	}
 
@@ -192,6 +195,7 @@ func TestResourceUnmarshalJSON(t *testing.T) {
 		{[]byte(`"arn:aws:s3:::mybucket/*"`), NewResource("mybucket/*"), false},
 		{[]byte(`"arn:aws:s3:::mybucket*/myobject"`), NewResource("mybucket*/myobject"), false},
 		{[]byte(`"arn:aws:s3:::mybucket?0/2010/photos/*"`), NewResource("mybucket?0/2010/photos/*"), false},
+		{[]byte(`"arn:aws:s3tables:::bucket/demo/table/*"`), Resource{Pattern: "bucket/demo/table/*", Type: ResourceARNS3Tables}, false},
 		{[]byte(`"mybucket/myobject*"`), Resource{}, true},
 		{[]byte(`"arn:aws:s3:::/*"`), Resource{}, true},
 	}
